@@ -68,15 +68,15 @@ class PDFMagnifier : public QLabel
 
 public:
 	PDFMagnifier(QWidget *parent, qreal inDpi);
-	void setPage(int p, qreal scale, const QRect& visibleRect);
+	void setPage(int p, qreal scale, const QRect &visibleRect);
 	void reshape();
-	
+
 public slots:
 	void setImage(const QPixmap &img, int pageNr);
-	
+
 protected:
 	virtual void paintEvent(QPaintEvent *event);
-	QPixmap & getConvertedImage();
+	QPixmap &getConvertedImage();
 
 private:
 	int oldshape;
@@ -88,9 +88,9 @@ private:
 	QPixmap	convertedImage;
 	bool	convertedImageIsGrayscale;
 	bool	convertedImageIsColorInverted;
-	
+
 	QPoint mouseTranslate;
-	
+
 	QPoint	imageLoc, mouseOffset;
 	QSize	imageSize;
 	qreal	imageDpi;
@@ -104,7 +104,7 @@ class PDFMovie: public Phonon::VideoPlayer
 {
 	Q_OBJECT
 public:
-	PDFMovie(PDFWidget* parent, Poppler::MovieAnnotation* annot, int page);
+	PDFMovie(PDFWidget *parent, Poppler::MovieAnnotation *annot, int page);
 	void place();
 protected:
 	void contextMenuEvent(QContextMenuEvent *);
@@ -114,7 +114,7 @@ public slots:
 	void setVolumeDialog();
 	void seekDialog();
 private:
-	QMenu* popup;
+	QMenu *popup;
 	QRectF boundary;
 	int page;
 };
@@ -133,9 +133,9 @@ class PDFWidget : public QLabel
 	Q_OBJECT
 
 public:
-	explicit PDFWidget(bool embedded=false);
+	explicit PDFWidget(bool embedded = false);
 	virtual ~PDFWidget();
-	
+
 	void setDocument(const QSharedPointer<Poppler::Document> &doc);
 	void setPDFDocument(PDFDocument *docu);
 
@@ -145,14 +145,14 @@ public:
 	void resetMagnifier();
 	Q_INVOKABLE int normalizedPageIndex(int pageIndex);
 	Q_INVOKABLE void goToPageDirect(int pageIndex, bool sync);
-	Q_INVOKABLE void setHighlightPath(const int pageIndex, const QPainterPath& path);
+	Q_INVOKABLE void setHighlightPath(const int pageIndex, const QPainterPath &path);
 	Q_INVOKABLE int getHighlightPage() const;
-	Q_INVOKABLE void goToDestination(const QString& destName);
+	Q_INVOKABLE void goToDestination(const QString &destName);
 	Q_INVOKABLE void goToPageRelativePosition(int page, float xinpage, float yinpage);
 	Q_INVOKABLE int getPageIndex();
 	Q_INVOKABLE void reloadPage(bool sync = true);
 	void updateStatusBar();
-	void setGridSize(int gx, int gy, bool setAsDefault=false);
+	void setGridSize(int gx, int gy, bool setAsDefault = false);
 	Q_INVOKABLE int visiblePages() const;
 	Q_INVOKABLE int pseudoNumPages() const;
 	Q_INVOKABLE int realNumPages() const;
@@ -160,23 +160,23 @@ public:
 	Q_INVOKABLE int gridCols() const;
 	Q_INVOKABLE int gridRowHeight() const;
 	Q_INVOKABLE int gridBorder() const;
-	Q_INVOKABLE PDFDocument * getPDFDocument();
+	Q_INVOKABLE PDFDocument *getPDFDocument();
 	Q_INVOKABLE int getPageOffset() const;
 	autoScaleOption getScaleOption() { return scaleOption; }
 	double totalScaleFactor() const;
 
 	int currentPageHistoryIndex() const;
 	const QList<int> currentPageHistory() const;
-	
+
 	QPoint gridPagePosition(int pageIndex) const;
 	QRect gridPageRect(int pageIndex) const;
-	int gridPageIndex(const QPoint& position) const;
-	void mapToScaledPosition(const QPoint& position, int & page, QPointF& scaledPos) const;
-	QPoint mapFromScaledPosition(int page, const QPointF& scaledPos) const;
-	int pageFromPos(const QPoint& pos) const;
+	int gridPageIndex(const QPoint &position) const;
+	void mapToScaledPosition(const QPoint &position, int &page, QPointF &scaledPos) const;
+	QPoint mapFromScaledPosition(int page, const QPointF &scaledPos) const;
+	int pageFromPos(const QPoint &pos) const;
 	QRect pageRect(int page) const;
 	QSizeF maxPageSizeF() const;
-	QSizeF gridSizeF(bool ignoreVerticalGrid=false) const;
+	QSizeF gridSizeF(bool ignoreVerticalGrid = false) const;
 	QRectF horizontalTextRangeF();
 
 	Q_INVOKABLE void zoom(qreal scale);
@@ -191,13 +191,13 @@ protected slots: //not private, so scripts have access
 	void goForward();
 	void goBack();
 	void doPageDialog();
-	
+
 	void fitWidth(bool checked = true);
 	void fitTextWidth(bool checked = true);
 	void zoomIn();
 	void zoomOut();
 	void jumpToSource();
-	
+
 	void upOrPrev();
 	void leftOrPrev();
 	void pageUpOrPrev();
@@ -207,22 +207,22 @@ protected slots: //not private, so scripts have access
 	void pageDownOrNext();
 
 	void clearHighlight();
-	
+
 public slots:
 	void setSinglePageStep(bool step);
 	void windowResized();
 	void fitWindow(bool checked = true);
-	void setTool(int tool);	
-	void syncWindowClick(const QPoint& p, bool activate);
+	void setTool(int tool);
+	void syncWindowClick(const QPoint &p, bool activate);
 	void syncCurrentPage(bool activate);
 	void fixedScale(qreal scale = 1.0);
-	void setImage(QPixmap img,int pageNr);
+	void setImage(QPixmap img, int pageNr);
 
 signals:
 	void changedPage(int, bool);
 	void changedZoom(qreal);
 	void changedScaleOption(autoScaleOption);
-	void syncClick(int, const QPointF&, bool activate); //page position in page coordinates
+	void syncClick(int, const QPointF &, bool activate); //page position in page coordinates
 
 protected:
 	virtual void paintEvent(QPaintEvent *event);
@@ -249,19 +249,19 @@ private:
 	void init();
 	void adjustSize();
 	void updateCursor();
-	void updateCursor(const QPoint& pos);
+	void updateCursor(const QPoint &pos);
 	QRect mapPopplerRectToWidget(QRectF rect, const QSizeF &pageSize) const;
 	void useMagnifier(const QMouseEvent *inEvent);
-	void goToDestination(const Poppler::LinkDestination& dest);
+	void goToDestination(const Poppler::LinkDestination &dest);
 	void doLink(const Poppler::Link *link);
 	void annotationClicked(Poppler::Annotation *annotation, int page);
-	void doZoom(const QPoint& clickPos, int dir, qreal newScaleFactor=1.0);
+	void doZoom(const QPoint &clickPos, int dir, qreal newScaleFactor = 1.0);
+
+	PDFScrollArea *getScrollArea();
 
-	PDFScrollArea* getScrollArea();
-	
 	QSharedPointer<Poppler::Document> document;
 	QMutex textwidthCalculationMutex;
-	
+
 	//QList<int> pages;
 	Poppler::Link		*clickedLink;
 	Poppler::Annotation	*clickedAnnotation;
@@ -273,7 +273,7 @@ private:
 	autoScaleOption scaleOption;
 
 	float summedWheelDegrees;
-	
+
 	int docPages;
 	qreal			saveScaleFactor;
 	autoScaleOption	saveScaleOption;
@@ -305,7 +305,7 @@ private:
 	QPainterPath	highlightPath;
 	int highlightPage;
 	QTimer highlightRemover;
-	
+
 	static QCursor	*magnifierCursor;
 	static QCursor	*zoomInCursor;
 	static QCursor	*zoomOutCursor;
@@ -319,13 +319,14 @@ private:
 	PDFDocument *pdfdocument;
 };
 
-class PDFSearchResult {
+class PDFSearchResult
+{
 public:
-	explicit PDFSearchResult(const PDFDocument* pdfdoc = NULL, int page = -1, QRectF rect = QRectF())
+	explicit PDFSearchResult(const PDFDocument *pdfdoc = NULL, int page = -1, QRectF rect = QRectF())
 		: doc(pdfdoc), pageIdx(page), selRect(rect)
 	{ }
 
-	const PDFDocument* doc;
+	const PDFDocument *doc;
 	int pageIdx;
 	QRectF selRect;
 };
@@ -339,12 +340,13 @@ class PDFScrollArea;
 class PDFDocument : public QMainWindow, private Ui::PDFDocument
 {
 	Q_OBJECT
+
 	Q_PROPERTY(QString fileName READ fileName)
 
 public:
-    explicit PDFDocument(PDFDocumentConfig* const pdfConfig, bool embedded=false);
+	explicit PDFDocument(PDFDocumentConfig *const pdfConfig, bool embedded = false);
 	virtual ~PDFDocument();
-	
+
 	enum DisplayFlagsEnum {
 		NoDisplayFlags = 0x0000,
 		FocusEmbedded = 0x0001,
@@ -360,10 +362,7 @@ public:
 	Q_DECLARE_FLAGS(DisplayFlags, DisplayFlagsEnum)
 
 	static PDFDocument *findDocument(const QString &fileName);
-	static QList<PDFDocument*> documentList()
-	{
-		return docList;
-	}
+	static QList<PDFDocument *> documentList() { return docList; }
 
 	Q_INVOKABLE QString fileName() const { return curFile; }
 	Q_INVOKABLE QFileInfo getMasterFile() const { return masterFile; }
@@ -375,20 +374,14 @@ public:
 	Q_INVOKABLE void showPage(int page);
 	Q_INVOKABLE void setResolution(int res);
 	void resetMagnifier();
-	Q_INVOKABLE void goToDestination(const QString& destName);
+	Q_INVOKABLE void goToDestination(const QString &destName);
 	Q_INVOKABLE void goToPage(const int page);
 	Q_INVOKABLE void focus();
-	bool hasSyncData()
-	{
-		return scanner != NULL;
-	}
+	bool hasSyncData() { return scanner != NULL; } 
 
-	const QSharedPointer<Poppler::Document> & popplerDoc() const
-	{
-		return document;
-	}
-	
-	Q_INVOKABLE PDFWidget *widget(){ return pdfWidget; }
+	const QSharedPointer<Poppler::Document> &popplerDoc() const { return document; }
+
+	Q_INVOKABLE PDFWidget *widget() { return pdfWidget; }
 	const PDFWidget *widget() const { return pdfWidget; }
 
 	bool followCursor() const;
@@ -398,8 +391,8 @@ public:
 	bool embeddedMode;
 	bool autoClose;
 
-    void setStateEnlarged(bool state);
-	
+	void setStateEnlarged(bool state);
+
 protected:
 	virtual void changeEvent(QEvent *event);
 	virtual void closeEvent(QCloseEvent *event);
@@ -413,37 +406,37 @@ protected:
 
 public slots:
 	void reloadSettings();
-	void loadCurrentFile(bool fillCache=true);
-	void fillRenderCache(int pg=-1);
+	void loadCurrentFile(bool fillCache = true);
+	void fillRenderCache(int pg = -1);
 	void sideBySide();
-    void doFindDialog(const QString command="");
+	void doFindDialog(const QString command = "");
 	void doFindAgain();
 	void goToSource();
 	void toggleFullScreen(const bool fullscreen);
-	int syncFromSource(const QString& sourceFile, int lineNo, DisplayFlags displayFlags);  // lineNo is 0-based
-	void syncFromView(const QString& pdfFile, const QFileInfo& masterFile, int page);
-	void loadFile(const QString &fileName, const QFileInfo& masterFile, DisplayFlags displayFlags=DisplayFlagsEnum(Raise|Focus));
+	int syncFromSource(const QString &sourceFile, int lineNo, DisplayFlags displayFlags);  // lineNo is 0-based
+	void syncFromView(const QString &pdfFile, const QFileInfo &masterFile, int page);
+	void loadFile(const QString &fileName, const QFileInfo &masterFile, DisplayFlags displayFlags = DisplayFlagsEnum(Raise | Focus));
 	void printPDF();
 	void setAutoHideToolbars(bool enabled);
 	void hideToolbars();
 	void showToolbars();
-    void setToolbarIconSize(int sz);
+	void setToolbarIconSize(int sz);
 	void showMessage(const QString &text);
 
-    void splitMergeTool();
+	void splitMergeTool();
 private slots:
 	void fileOpen();
-	
+
 	void enablePageActions(int, bool);
 	void enableZoomActions(qreal);
 	void adjustScaleActions(autoScaleOption);
-	void syncClick(int page, const QPointF& pos, bool activate);
+	void syncClick(int page, const QPointF &pos, bool activate);
 	void stopReloadTimer();
 	void reloadWhenIdle();
 	void idleReload();
 
 	void runExternalViewer();
-    void runInternalViewer();
+	void runInternalViewer();
 	void toggleEmbedded();
 	void runQuickBuild();
 
@@ -463,39 +456,39 @@ private slots:
 
 	void search(bool backward, bool incremental);
 public:
-	void search(const QString& searchText, bool backward, bool incremental, bool caseSensitive, bool sync);
+	void search(const QString &searchText, bool backward, bool incremental, bool caseSensitive, bool sync);
 	void search();
-	static QString debugSyncTeX(const QString& filename);
+	static QString debugSyncTeX(const QString &filename);
 private slots:
 	void gotoAnnotation(const PDFAnnotation *ann);
 
 	void zoomFromAction();
 	void zoomSliderChange(int pos = 0);
-    void enlarge();
-    void shrink();
+	void enlarge();
+	void shrink();
 signals:
 	void documentClosed();
 	void documentLoaded();
-	void syncSource(const QString& sourceFile, int line, bool activate, const QString& guessedWord); //view -> source
-	void syncView(const QString& pdfFile, const QFileInfo& masterFile, int page); //view -> other view
+	void syncSource(const QString &sourceFile, int line, bool activate, const QString &guessedWord); //view -> source
+	void syncView(const QString &pdfFile, const QFileInfo &masterFile, int page); //view -> other view
 	void focusEditor();
-	void fileDropped(const QUrl& url);
+	void fileDropped(const QUrl &url);
 
-	void runCommand(const QString& command, const QFileInfo& masterFile, const QFileInfo& currentFile, int linenr);
+	void runCommand(const QString &command, const QFileInfo &masterFile, const QFileInfo &currentFile, int linenr);
 
 	void triggeredAbout();
 	void triggeredManual();
 	void triggeredQuit();
 	void triggeredPlaceOnLeft();
 	void triggeredConfigure();
-    void triggeredEnlarge();
-    void triggeredShrink();
-	
+	void triggeredEnlarge();
+	void triggeredShrink();
+
 	void triggeredClone();
 
 private:
-    void init(bool embedded=false);
-    void setupMenus();
+	void init(bool embedded = false);
+	void setupMenus();
 	void setCurrentFile(const QString &fileName);
 	void loadSyncData();
 
@@ -509,13 +502,13 @@ private:
 	int lastSyncLineNumber;
 
 	QSharedPointer<Poppler::Document> document;
-	
+
 	PDFWidget	*pdfWidget;
 	PDFScrollArea	*scrollArea;
 	MessageFrame *messageFrame;
-	TitledPanel * annotationPanel;
-	PDFAnnotations * annotations;
-	PDFAnnotationTableView * annotationTable;
+	TitledPanel *annotationPanel;
+	PDFAnnotations *annotations;
+	PDFAnnotationTableView *annotationTable;
 
 	QMenuBar *menubar;
 	QMenu *menuHelp;
@@ -542,18 +535,18 @@ private:
 	QLabel *pageLabel;
 	QToolButton *scaleButton;
 	QSlider *zoomSlider;
-	QList<QAction*> recentFileActions;
-	QShortcut* exitFullscreen;
+	QList<QAction *> recentFileActions;
+	QShortcut *exitFullscreen;
 
 	QFileSystemWatcher *watcher;
 	QTimer *reloadTimer;
-	
+
 	synctex_scanner_t scanner;
-	
-	static QList<PDFDocument*> docList;
-	
+
+	static QList<PDFDocument *> docList;
+
 	PDFDock *dwClock, *dwOutline, *dwFonts, *dwInfo, *dwOverview;
-	bool dwVisOutline,dwVisFonts,dwVisInfo,dwVisSearch,dwVisOverview;
+	bool dwVisOutline, dwVisFonts, dwVisInfo, dwVisSearch, dwVisOverview;
 	bool wasContinuous;
 	PDFSearchDock *dwSearch;
 
