@@ -10,9 +10,10 @@
 class SearchResultWidget : public QWidget
 {
 	Q_OBJECT
+
 public:
 	explicit SearchResultWidget(QWidget *parent = 0);
-	
+
 	void setQuery(SearchQuery *sq);
 	SearchQuery::Scope searchScope() const;
 
@@ -43,10 +44,13 @@ private:
 };
 
 
-class SearchTreeDelegate: public QItemDelegate {
+class SearchTreeDelegate: public QItemDelegate
+{
 	Q_OBJECT
+
 public:
 	SearchTreeDelegate(QObject *parent = 0);
+
 protected:
 	void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
 	QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
