@@ -15,7 +15,8 @@ Session::Session(const Session &s)
 	m_pdfEmbedded = s.m_pdfEmbedded;
 }
 
-bool Session::load(const QString &file) {
+bool Session::load(const QString &file)
+{
 	if (!QFileInfo(file).isReadable()) return false;
 	QSettings s(file, QSettings::IniFormat);
 	if (!s.childGroups().contains("Session")) return false;
@@ -23,7 +24,7 @@ bool Session::load(const QString &file) {
 	s.beginGroup("Session");
 	QStringList groups = s.childGroups();
 	QDir dir = QFileInfo(file).dir();
-	for (int i=0; i<1000; i++) {
+	for (int i = 0; i < 1000; i++) {
 		if (!groups.contains(QString("File%1").arg(i)))
 			break;
 		s.beginGroup(QString("File%1").arg(i));
@@ -53,7 +54,8 @@ bool Session::load(const QString &file) {
 
 // legacy code to support reading the session information which was previously stored in the config file (TXS <= 2.5.1)
 // may be removed later on
-bool Session::load(const ConfigManager &config) {
+bool Session::load(const ConfigManager &config)
+{
 	QStringList sessionFilesToRestore = config.getOption("Files/Session/Files").toStringList();
 	QList<QVariant> sessionCurRowsToRestore = config.getOption("Files/Session/curRows").value<QList<QVariant> >();
 	QList<QVariant> sessionCurColsToRestore = config.getOption("Files/Session/curCols").value<QList<QVariant> >();
@@ -62,12 +64,12 @@ bool Session::load(const ConfigManager &config) {
 	QString sessionMaster = config.getOption("Files/Session/MasterFile").toString();
 	QList<QVariant> bookmarkList = config.getOption("Files/Bookmarks").value<QList<QVariant> >();
 
-	for (int i=0; i<sessionFilesToRestore.size(); i++){
+	for (int i = 0; i < sessionFilesToRestore.size(); i++) {
 		FileInSession f;
 		f.fileName = sessionFilesToRestore[i];
-		f.cursorLine = sessionCurRowsToRestore.value(i,QVariant(0)).toInt();
-		f.cursorCol = sessionCurColsToRestore.value(i,0).toInt();
-		f.firstLine = sessionFirstLinesToRestore.value(i,0).toInt();
+		f.cursorLine = sessionCurRowsToRestore.value(i, QVariant(0)).toInt();
+		f.cursorCol = sessionCurColsToRestore.value(i, 0).toInt();
+		f.firstLine = sessionFirstLinesToRestore.value(i, 0).toInt();
 		m_files.append(f);
 	}
 	m_masterFile = sessionMaster;
@@ -76,15 +78,15 @@ bool Session::load(const ConfigManager &config) {
 	return true;
 }
 
-
-bool Session::save(const QString &file, bool relPaths) const {
+bool Session::save(const QString &file, bool relPaths) const
+{
 	if (!isFileRealWritable(file)) return false;
 	QSettings s(file, QSettings::IniFormat);
 	s.clear();
 	s.beginGroup("Session");
 	s.setValue("FileVersion", 1); // increment if format changes are applied later on. This might be used for version-dependent loading.
 	QDir dir = QFileInfo(file).dir();
-	for (int i=0; i<m_files.count(); i++) {
+	for (int i = 0; i < m_files.count(); i++) {
 		s.beginGroup(QString("File%1").arg(i));
 		s.setValue("FileName", fmtPath(dir, m_files[i].fileName, relPaths));
 		s.setValue("Line", m_files[i].cursorLine);
@@ -106,11 +108,13 @@ bool Session::save(const QString &file, bool relPaths) const {
 	return true;
 }
 
-void Session::addFile(FileInSession f) {
+void Session::addFile(FileInSession f)
+{
 	m_files.append(f);
 }
 
-QString Session::fmtPath(const QDir &dir, const QString &file, bool relPath) {
+QString Session::fmtPath(const QDir &dir, const QString &file, bool relPath)
+{
 	if (!relPath)
 		return file;
 	else
