@@ -13,7 +13,7 @@
 #define LIST_RESERVE(list, count)
 #endif
 
-extern const char* TEXSTUDIO_HG_REVISION;
+extern const char *TEXSTUDIO_HG_REVISION;
 
 bool getDiskFreeSpace(const QString &path, quint64 &freeBytes);
 
@@ -26,35 +26,35 @@ QString getUserName();
 
 QString getUserDocumentFolder();
 
-QStringList findResourceFiles(const QString& dirName, const QString& filter, QStringList additionalPreferredPaths = QStringList());
+QStringList findResourceFiles(const QString &dirName, const QString &filter, QStringList additionalPreferredPaths = QStringList());
 //returns the real name of a resource file
-QString findResourceFile(const QString& fileName, bool allowOverride = false, QStringList additionalPreferredPaths = QStringList(), QStringList additionalFallbackPaths = QStringList());
+QString findResourceFile(const QString &fileName, bool allowOverride = false, QStringList additionalPreferredPaths = QStringList(), QStringList additionalFallbackPaths = QStringList());
 
 extern bool modernStyle;
 extern bool useSystemTheme;
 
-extern QCache<QString,QIcon>IconCache;
+extern QCache<QString, QIcon>iconCache;
 
-QString getRealIconFile(const QString& icon);
-QIcon getRealIcon(const QString& icon);
-QIcon getRealIconCached(const QString& icon);
+QString getRealIconFile(const QString &icon);
+QIcon getRealIcon(const QString &icon);
+QIcon getRealIconCached(const QString &icon);
 
 //returns if the file is writable (QFileInfo.isWritable works in different ways on Windows and Linux)
-bool isFileRealWritable(const QString& filename);
+bool isFileRealWritable(const QString &filename);
 //returns if the file exists and is writable
-bool isExistingFileRealWritable(const QString& filename);
+bool isExistingFileRealWritable(const QString &filename);
 //adds QDir::separator() if the path end not with it
-QString ensureTrailingDirSeparator(const QString& dirPath);
+QString ensureTrailingDirSeparator(const QString &dirPath);
 // replaces "somdir/file.ext" to "somedir/file.newext"
-QString replaceFileExtension(const QString& filename, const QString& newExtension, bool appendIfNoExt=false);
-QString getRelativeBaseNameToPath(const QString & file, QString basepath, bool baseFile=false, bool keepSuffix=false);
+QString replaceFileExtension(const QString &filename, const QString &newExtension, bool appendIfNoExt = false);
+QString getRelativeBaseNameToPath(const QString &file, QString basepath, bool baseFile = false, bool keepSuffix = false);
 QString getPathfromFilename(const QString &compFile);
-QString findAbsoluteFilePath(const QString & relName, const QString &extension, const QStringList &searchPaths, const QString& fallbackPath);
-QString getNonextistentFilename(const QString &guess, const QString &fallback=QString());
+QString findAbsoluteFilePath(const QString &relName, const QString &extension, const QStringList &searchPaths, const QString &fallbackPath);
+QString getNonextistentFilename(const QString &guess, const QString &fallback = QString());
 
 QString getEnvironmentPath();
 QStringList getEnvironmentPathList();
-void updatePathSettings(QProcess* proc, QString additionalPaths);
+void updatePathSettings(QProcess *proc, QString additionalPaths);
 
 QString getTerminalCommand();
 
@@ -66,27 +66,29 @@ bool isRetinaMac();
 //check if the run-time qt version is higher than the given version (e.g. 4,3)
 bool hasAtLeastQt(int major, int minor);
 
-bool connectUnique(const QObject * sender, const char * signal, const QObject * receiver, const char * method);
+bool connectUnique(const QObject *sender, const char *signal, const QObject *receiver, const char *method);
 
 QStringList envKeys(const QProcessEnvironment &env);
 
-QString execCommand(const QString & cmd);
+QString execCommand(const QString &cmd);
+
 
 class ThreadBreaker : public QThread
 {
 public:
 	static void sleep(int s);
 	static void msleep(unsigned long ms);
-	static void forceTerminate(QThread* t = 0);
+	static void forceTerminate(QThread *t = 0);
 };
 
 
 class SafeThread: public QThread
 {
 	Q_OBJECT
+
 public:
 	SafeThread();
-	SafeThread(QObject* parent);
+	SafeThread(QObject *parent);
 	void wait(unsigned long time = 60000);
 	bool crashed;
 };
